Blogs
=====

Codes in this repository are demo codes for a few entries of my blog,
`Everything about Data Analytics
https://datawarrior.wordpress.com/`_, and the corresponding entries are:

`Starting the Journey of Topological Data Analysis (TDA)
<https://datawarrior.wordpress.com/2015/08/03/tda-1-starting-the-journey-of-topological-data-analysis-tda/>`_ (August 3, 2015)

`Constructing Connectivities
<https://datawarrior.wordpress.com/2015/09/14/tda-2-constructing-connectivities/>`_ (September 14, 2015)

`Homology and Betti Numbers
<https://datawarrior.wordpress.com/2015/11/03/tda-3-homology-and-betti-numbers/>`_ (November 3, 2015)

`Topology in Physics and Computing
<https://datawarrior.wordpress.com/2015/11/10/mathanalytics-6-topology-in-physics-and-computing/>`_ (November 10, 2015)

`Persistence
<https://datawarrior.wordpress.com/2015/12/20/tda-4-persistence/>`_ (December 20, 2015)

`Topological Phases
<https://datawarrior.wordpress.com/2016/10/06/topological-phases/>`_ (October 6, 2016)

`moguTDA: Python package for Simplicial Complex
<https://datawarrior.wordpress.com/2018/07/02/mogutda-python-package-for-simplicial-complex/>`_ (July 2, 2018)

Home: :doc:`index`
